@@ -27,7 +27,7 @@ class DropN900(QtCore.QObject):
         self.ui.show()
         self.reset_variables()
         self.check_for_data_folder()
-        self.check_for_auth(self.abs_path(".token"))
+        self.check_for_auth(self.abs_config_path("token.ini"))
 
     def reset_variables(self):
         self.authenticator = None
@@ -39,10 +39,12 @@ class DropN900(QtCore.QObject):
         if home_dir.absolutePath() == "/home/user":
             if not home_dir.cd("DropN900"):
                 home_dir.mkdir("DropN900")
+            if not home_dir.cd(".dropn900"):
+                home_dir.mkdir(".dropn900")
                 
-    def check_for_auth(self, file):
+    def check_for_auth(self, filename):
         token_config = SafeConfigParser()
-        token_config.read(file)
+        token_config.read(filename)
         try:
             access_key = token_config.get("token", "key")
             access_secret = token_config.get("token", "secret")
@@ -64,13 +66,13 @@ class DropN900(QtCore.QObject):
         token_config.set("token", "secret", access_token.secret)
         token_config.set("token", "key", access_token.key)
         
-        write_file = open(self.abs_path(".token"), "w")
+        write_file = open(self.abs_config_path("token.ini"), "w")
         token_config.write(write_file)
         write_file.close()
 
     def reset_auth(self):
         try:
-            os.remove(self.abs_path(".token"))
+            os.remove(self.abs_config_path("token.ini"))
         except OSError:
             pass
         self.start_trusted_auth()
@@ -149,12 +151,17 @@ class DropN900(QtCore.QObject):
     def set_abs_path(self, maemo_env):
         if maemo_env:
             self.app_root = "/opt/dropn900/"
+            self.config_root = "/home/user/.dropn900/"
         else:
             self.app_root = ""
+            self.config_root = ""
             
     def abs_path(self, rel_path):
         return self.app_root + rel_path
         
+    def abs_config_path(self, config):
+        return self.config_root + config
+        
 """ This is the main function that starts the program """
 
 if __name__ == "__main__":
