@@ -88,7 +88,7 @@ class UiController:
         self.trusted_login_widget = QWidget()
         self.trusted_login_ui = Ui_TrustedLoginWidget()
         self.trusted_login_ui.setupUi(self.trusted_login_widget)
-        self.trusted_login_ui.label_icon.setPixmap(QPixmap("ui/images/synced_with_dropbox_logo.png"))
+        self.trusted_login_ui.label_icon.setPixmap(QPixmap(self.controller.abs_path("ui/images/synced_with_dropbox_logo.png")))
 
         # Connects
         self.trusted_login_ui.button_auth.clicked.connect(self.try_trusted_login)
@@ -135,7 +135,7 @@ class UiController:
         self.loading_widget.hide()
 
         # Init loading animation
-        self.loading_animation = QMovie("ui/images/loading.gif", "GIF", self.loading_ui.load_animation_label)
+        self.loading_animation = QMovie(self.controller.abs_path("ui/images/loading.gif"), "GIF", self.loading_ui.load_animation_label)
         self.loading_animation.setCacheMode(QMovie.CacheAll)
         self.loading_animation.setSpeed(150)
         self.loading_animation.setScaledSize(QtCore.QSize(48,48))
@@ -145,8 +145,8 @@ class UiController:
         self.information_message_timer = QTimer()
         self.information_message_timer.setSingleShot(True)
         self.information_message_timer.timeout.connect(self.hide_information_message)
-        self.information_icon_ok = QPixmap("ui/icons/check.png").scaled(24,24)
-        self.information_icon_error = QPixmap("ui/icons/cancel.png").scaled(24,24)
+        self.information_icon_ok = QPixmap(self.controller.abs_path("ui/icons/check.png")).scaled(24,24)
+        self.information_icon_error = QPixmap(self.controller.abs_path("ui/icons/cancel.png")).scaled(24,24)
 
         self.log("UI initialised...")
 
@@ -351,7 +351,7 @@ class UiController:
         self.webview_load_url(url)
         self.browser_ui.label_info.hide()
         self.browser_ui.button_done.setText("Back")
-        self.browser_ui.button_done.setIcon(QIcon("ui/icons/back.png"))
+        self.browser_ui.button_done.setIcon(QIcon(self.controller.abs_path("ui/icons/back.png")))
         self.switch_context("browser")
 
     def item_download(self):
@@ -487,6 +487,9 @@ class TreeController:
         # Click tracking
         self.clicked_items = {}
         
+        # Supported thumb image formats
+        self.supported_reader_formats = QImageReader.supportedImageFormats()
+        
         # Thumbs init
         self.thumbs = {}
 
@@ -683,7 +686,7 @@ class TreeController:
             load_widget.setStyleSheet("QLabel { background-color: transparent; }")
 
             # Create animation
-            load_anim = QMovie("ui/images/loading_tree.gif", "GIF", load_widget)
+            load_anim = QMovie(self.controller.abs_path("ui/images/loading_tree.gif"), "GIF", load_widget)
             load_anim.setCacheMode(QMovie.CacheAll)
             load_anim.setSpeed(150)
             load_anim.setScaledSize(QtCore.QSize(30,30))
@@ -699,7 +702,7 @@ class TreeController:
             del child
 
     def set_icon(self, item_type, tree_item, index = 0, label = None):
-        base_path = "ui/icons/"
+        base_path = self.controller.app_root + "ui/icons/"
         base_type = item_type.split("/")[0]
         # item type
         if item_type == "folder":
@@ -813,8 +816,7 @@ class TreeController:
         # Check from qt if the format is accepptable
         format = image_path.split(".")[-1]
         try:
-            supported = QImageReader.supportedImageFormats()
-            supported.index(QtCore.QByteArray(format.lower()))
+            self.supported_reader_formats.index(QtCore.QByteArray(format.lower()))
             return True
         except ValueError:
             return False
